MethodChannelSunmiMtb class

Method channel implementation of SunmiMtbPlatform.

Inheritance

Constructors

MethodChannelSunmiMtb()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate(String activationCode) Future<String?>
Activates the SoftPOS terminal with the given activationCode.
override
getDeviceId() Future<String?>
Gets the device's Android ID.
override
init() Future<void>
Initializes the plugin.
override
isInstalled() Future<bool>
Checks if the MineSec SoftPOS app is installed on the device.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saleTransaction(String amount, String posMessageId) Future<Map<String, dynamic>?>
Initiates a sale transaction.
override
toString() String
A string representation of this object.
inherited
warmUp() Future<String?>
Triggers the SoftPOS warm-up process.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited