settlement method

Future<Map<String, dynamic>?> settlement(
  1. String posMessageId
)

Triggers a settlement transaction.

Returns a Map containing both the request parameters and the settlement response data, or null if no result.

Implementation

Future<Map<String, dynamic>?> settlement(String posMessageId) {
  throw UnimplementedError('settlement() has not been implemented.');
}