SunmiMtbPlatform class abstract
Platform interface for the SunmiMtb plugin.
Platform-specific implementations should extend this class and override its methods, then register themselves via instance setter.
- Inheritance
-
- Object
- PlatformInterface
- SunmiMtbPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activate(
String activationCode) → Future< String?> -
Activates the SoftPOS terminal with the given
activationCode. -
getDeviceId(
) → Future< String?> - Gets the device's Android ID.
-
init(
) → Future< void> - Initializes the plugin.
-
isInstalled(
) → Future< bool> - Checks if the MineSec SoftPOS app is installed on the device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saleTransaction(
String amount, String posMessageId) → Future< Map< String, dynamic> ?> - Initiates a sale transaction.
-
toString(
) → String -
A string representation of this object.
inherited
-
warmUp(
) → Future< String?> - Triggers the SoftPOS warm-up process.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SunmiMtbPlatform
-
The default instance of SunmiMtbPlatform.
getter/setter pair